@@ -1,9 +1,11 @@
 from actionpack.action import Action
 from actionpack.procedure import Procedure
+from actionpack.procedure import KeyedProcedure
 
 
 __all__ = [
     'Action',
-    'Procedure'
+    'Procedure',
+    'KeyedProcedure'
 ]
 
