@@ -6,7 +6,10 @@ class WriteBytes(Action):
     def __init__(self, filename: str, bytes_to_write: bytes, overwrite: bool=False):
         self.path = Path(filename)
         self.overwrite = overwrite
-        self.instruction = lambda: self.path.write_bytes(bytes_to_write)
+        self.bytes_to_write = bytes_to_write
+
+    def instruction(self) -> int:
+        return self.path.write_bytes(self.bytes_to_write)
 
     def validate(self):
         if self.path.exists() and not self.overwrite:
